@@ -230,3 +230,29 @@ def is_valid_ss58_address(value: str, valid_ss58_format: Optional[int] = None) -
         return False
 
     return True
+
+
+def get_ss58_format(ss58_address: str) -> int:
+    """
+    Returns the SS58 format for given SS58 address
+
+    Parameters
+    ----------
+    ss58_address
+
+    Returns
+    -------
+    int
+    """
+    address_decoded = base58.b58decode(ss58_address)
+
+    if address_decoded[0] & 0b0100_0000:
+        ss58_format = ((address_decoded[0] & 0b0011_1111) << 2) | (address_decoded[1] >> 6) | \
+                      ((address_decoded[1] & 0b0011_1111) << 8)
+    else:
+        ss58_format = address_decoded[0]
+
+    if ss58_format in [46, 47]:
+        raise ValueError(f"{ss58_format} is a reserved SS58 format")
+
+    return ss58_format
