@@ -30,8 +30,8 @@ class TestScaleDecoderClasses(unittest.TestCase):
     def setUpClass(cls):
         cls.runtime_config = RuntimeConfigurationObject()
         cls.runtime_config.clear_type_registry()
-        cls.runtime_config.update_type_registry(load_type_registry_preset("metadata_types"))
-        cls.runtime_config.update_type_registry(load_type_registry_preset("default"))
+        cls.runtime_config.update_type_registry(load_type_registry_preset("core"))
+        cls.runtime_config.update_type_registry(load_type_registry_preset("legacy"))
 
     def test_valid_decoding_classes(self):
         for type_string in self.runtime_config.type_registry['types'].keys():
@@ -40,36 +40,6 @@ class TestScaleDecoderClasses(unittest.TestCase):
 
             self.assertIsNotNone(decoding_cls, msg='"{}" didn\'t return decoding class'.format(type_string))
 
-            # Try to decode type mapping if present
-            if decoding_cls.type_mapping:
-                for sub_type_string in decoding_cls.type_mapping:
-
-                    if type(sub_type_string) in [list, tuple]:
-                        sub_type_string = sub_type_string[1]
-
-                    if sub_type_string is not None:
-
-                        if type(sub_type_string) is dict:
-                            sub_type_mapping = [[k, v] for k, v in sub_type_string.items()]
-                            sub_decoding_cls = type(type_string, (Struct,), {'type_mapping': sub_type_mapping})
-                        else:
-                            sub_decoding_cls = self.runtime_config.get_decoder_class(sub_type_string)
-
-                        self.assertIsNotNone(sub_decoding_cls,
-                                             msg=f' Sub type "{sub_type_string}" didn\'t return decoding class')
-
-                        # Try to decode sub_type if present
-                        if sub_decoding_cls.sub_type:
-                            if sub_decoding_cls.sub_type[0] == '(':
-                                sub_sub_type_parts = [sub_decoding_cls.sub_type]
-                            else:
-                                sub_sub_type_parts = sub_decoding_cls.sub_type.split(',')
-
-                            for sub_sub_type_part in sub_sub_type_parts:
-                                sub_sub_decoding_cls = self.runtime_config.get_decoder_class(sub_sub_type_part.strip())
-                                self.assertIsNotNone(sub_sub_decoding_cls,
-                                                     msg=f' Sub type "{sub_sub_type_part}" didn\'t return decoding class')
-
 
 class TestMultipleRuntimeConfigurations(unittest.TestCase):
 
@@ -101,7 +71,7 @@ class TestRuntimeIdCache(unittest.TestCase):
 
     def test_runtime_id_cache_lookup(self):
         runtime_config = RuntimeConfigurationObject()
-        runtime_config.update_type_registry(load_type_registry_preset("default"))
+        runtime_config.update_type_registry(load_type_registry_preset("legacy"))
         runtime_config.update_type_registry(load_type_registry_preset("kusama"))
 
         self.assertEqual(1023, runtime_config.get_runtime_id_from_upgrades(54248))
@@ -109,7 +79,7 @@ class TestRuntimeIdCache(unittest.TestCase):
 
     def test_set_head(self):
         runtime_config = RuntimeConfigurationObject()
-        runtime_config.update_type_registry(load_type_registry_preset("default"))
+        runtime_config.update_type_registry(load_type_registry_preset("legacy"))
         runtime_config.update_type_registry(load_type_registry_preset("kusama"))
 
         self.assertIsNone(runtime_config.get_runtime_id_from_upgrades(99999999998))
